"use strict";

import 'react-native-url-polyfill/auto';
import Notabene from '@notabene/javascript-sdk';
import { EmbeddedComponentRN } from "./embedded-component.js";
export default class NotabeneRN extends Notabene {
  constructor(config) {
    super(config);
    this.resultDeepLink = config.resultDeepLink;
    this.componentDeepLink = config.componentDeepLink;
  }

  /**
   * Creates a new embedded component
   *
   * @param path - The path of the component
   * @param value - Transaction data
   * @param options - Optional transaction options
   * @param callbacks - Optional callback configuration
   * @returns A new EmbeddedComponent instance
   * @internal
   */
  createComponent(path, value, options, callbacks) {
    return new EmbeddedComponentRN(this.componentUrl(path, value, options, callbacks), this.resultDeepLink, value);
  }

  /**
   * Generates a URL for a Notabene component
   *
   * @param path - The path of the component
   * @param value - Transaction data
   * @param configuration - Optional transaction configuration
   * @param callbacks - Optional callback configuration
   * @returns component URL
   * @internal
   */
  componentUrl(path, value, configuration, callbacks) {
    const url = super.componentUrl(path, value, configuration, callbacks);
    const sdkUrl = new URL(url);
    sdkUrl.searchParams.set('redirect_uri', this.resultDeepLink);
    return sdkUrl.toString();
  }
}
//# sourceMappingURL=index.js.map